Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Create ¶
func Create(cfgPath string, cfg CreateConfig) error
Create takes path to a kind configuration file and creates a new kind instance in the VM based on the config file passed
Types ¶
type CreateConfig ¶
Click to show internal directories.
Click to hide internal directories.